summaryrefslogtreecommitdiff
path: root/test/test_ptamodel.py
diff options
context:
space:
mode:
authorBirte Kristina Friesel <birte.friesel@uos.de>2023-12-07 14:32:57 +0100
committerBirte Kristina Friesel <birte.friesel@uos.de>2023-12-07 14:32:57 +0100
commit2dfdb0e9839ccbd9b0f93025774480a089100dba (patch)
treeb7eaee7aa339e73ef962ced866873c6ec8887675 /test/test_ptamodel.py
parentb9695e80314fe91b891c9a2e3f792805b9c729bd (diff)
xv: calculate measures from samples rather than averaging intermediates
Diffstat (limited to 'test/test_ptamodel.py')
-rwxr-xr-xtest/test_ptamodel.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/test_ptamodel.py b/test/test_ptamodel.py
index b40289c..cd774c3 100755
--- a/test/test_ptamodel.py
+++ b/test/test_ptamodel.py
@@ -330,8 +330,8 @@ class TestSynthetic(unittest.TestCase):
# the Root Mean Square Deviation must not be greater the scale (i.e., standard deviation) of the normal distribution
# Low Mean Absolute Error (< 2)
self.assertTrue(static_quality["raw_state_1"]["duration"]["mae"] < 2)
- # Low Root Mean Square Deviation (< scale == 2)
- self.assertTrue(static_quality["raw_state_1"]["duration"]["rmsd"] < 2)
+ # Low Root Mean Square Deviation (< scale+eps == 2.02)
+ self.assertTrue(static_quality["raw_state_1"]["duration"]["rmsd"] < 2.02)
# Relatively low error percentage (~~ MAE * 100% / s1_duration_base)
self.assertAlmostEqual(
static_quality["raw_state_1"]["duration"]["smape"],